import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart' as http;

Future<ResponseModel> fetchBookDetails() async {
  final response =
      await http.get("https://www.googleapis.com/books/v1/volumes?q=physics");
  if (response.statusCode == 200) {
    final jsonresponse = json.decode(response.body);
    return ResponseModel.fromJson(jsonresponse);
  } else {
    throw Exception('Failed to load data');
  }
}

class ResponseModel {
  String kind;
  int totalitems;
  List<Items> items;
  ResponseModel({this.kind, this.totalitems, this.items});
  factory ResponseModel.fromJson(Map<String, dynamic> parsedJson) {
    var list = parsedJson['items'] as List;
    List<Items> listOfItems = list.map((i) => Items.fromJson(i)).toList();
    return ResponseModel(
        kind: parsedJson['kind'],
        totalitems: parsedJson['totalItems'],
        items: listOfItems);
  }
}

class Items {
  final String kind;
  final String id;
  final String etag;
  final String selflink;
  final Volume volumeinfo;
  Items({
    this.kind,
    this.id,
    this.etag,
    this.selflink,
    this.volumeinfo,
  });
  factory Items.fromJson(Map<String, dynamic> parsedJson) {
    Volume volume = Volume.fromJson(parsedJson['volumeInfo']);
    return Items(
      kind: parsedJson['kind'],
      id: parsedJson['id'],
      etag: parsedJson['etag'],
      selflink: parsedJson['selfLink'],
      volumeinfo: volume,
    );
  }
}

class Volume {
  final String title;
  final List<dynamic> authors;
  final List<dynamic> categories;
  final String thumbnail;
  final String publisher;
  final String publishedDate;
  final String description;
  Volume(
      {this.title,
      this.authors,
      this.categories,
      this.thumbnail,
      this.description,
      this.publishedDate,
      this.publisher});
  factory Volume.fromJson(Map<String, dynamic> parsedJson) {
    var listOfAuthors;
    if (parsedJson['authors'] == null) {
      listOfAuthors = ["Not Applicable"];
    } else {
      listOfAuthors = parsedJson['authors'] as List;
    }
    var listOfCategories;
    if (parsedJson['categories'] == null) {
      listOfCategories = ["Not Applicable"];
    } else {
      listOfCategories = parsedJson['categories'] as List;
    }
    return Volume(
      title: parsedJson['title'],
      authors: listOfAuthors,
      categories: listOfCategories,
      thumbnail: parsedJson['imageLinks']['thumbnail'],
      publisher: parsedJson['publisher'],
      publishedDate: parsedJson['publishedDate'],
      description: parsedJson['description'],
    );
  }
}
