/*
Widget Name:
- Custom Anatomy Card

Description:
- Cards contain content and actions about a single subject.
- As the name of Card indicates, this card can be reusable depends on the user input.
- This card has been divided into multiple sections and based on parameters provided by user it can be hidden.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-anatomy-card.dart';

Usage:
- Defining the callback and Reusable Card objects

  onclickCard(String sText, int nIndex) {
    print(nIndex);
    print(sText);
  }

 final MaterialCardData reusableCardata = new MaterialCardData(
      onRatingUpdate: (double rate) {
        print(rate);
      },
      btnGrpList1: [
      SizedBox(
      width: 5,
    ),
        RaisedButton(
        color: Colors.red,
        child: Text(
        'Click',
        style: TextStyle(fontSize: 16.0),
    ),
    shape: RoundedRectangleBorder(
    borderRadius: BorderRadius.circular(20.0),
    side: BorderSide(color: Colors.red)),
    onPressed: null,
    ),
    SizedBox(
    width: 5,
    ),
    RaisedButton(
    color: Colors.red,
    child: Text(
    'Click',
    style: TextStyle(fontSize: 16.0),
    ),
    shape: RoundedRectangleBorder(
    borderRadius: BorderRadius.circular(20.0),
    side: BorderSide(color: Colors.red)),
    onPressed: null,
    ),
    RaisedButton(
    color: Colors.red,
    child: Text(
    'Click',
    style: TextStyle(fontSize: 16.0),
    ),
    shape: RoundedRectangleBorder(
    borderRadius: BorderRadius.circular(20.0),
    side: BorderSide(color: Colors.red)),
    onPressed: null,
    ),
    SizedBox(
    width: 5,
    ),
    ],
    btnGrpList2: [
    FlatButton(
    child: Text(
    'Text',
    style: TextStyle(fontSize: 16.0),
    ),
    onPressed: () {},
    ),
    FlatButton(
    child: Text(
    'Text',
    style: TextStyle(fontSize: 16.0),
    ),
    onPressed: () {},
    ),
    ],
    imgType: 'Asset',
    imgPath: 'images/card1.png',
    containerHeight: 670,
    containerWidth: 352,
    imgHeight: 278,
    imgWidth: 300,
    icon: Icon(Icons.local_mall),
    visibilityCardImage: true,
    visibilityCardHeaderTile: true,
    visibilityCardFooter: true,
    visibilityCardActionBar: true,
    visibilityCardData: true,
    bodyText: 't');
Widget call:
              customAnatomyCard(reusableCardata, onclickCard),

****Note:
- imgType decides weather the image source is network image or asset image.
- Reusable card contains one rating bar.To update the user input rating, onRatingUpdate function is required.
- btnGrpList1 & btnGrpList2 are two individual list of widget, that will appear in the bottom part of reusable card.
- If user doesn't require buttons in bottom part, they have to declare empty list as a part of object.
- This card has been divided into multiple sections and based on parameters provided by user it can be hidden.The default behaviour is given below.
  Ex:-
      visibilityCardImage: true,
      visibilityCardHeaderTile: false,
      visibilityCardFooter: true,
      visibilityCardActionBar: false,
      visibilityCardData: false,
Author:
- Satyabrat Padhy
*/

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';

import 'package:rapid_widgets_library/consts.dart' as constants;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customAnatomyCard(
    MaterialCardData data, Function(String, int) callback) {
  ImageProvider image;
  if (data.imgType != null && data.imgType == constants.Asset ||
      data.imgType == constants.asset) {
    image = (data.imgPath == null)
        ? AssetImage(constants.cardImagePath)
        : AssetImage(data.imgPath);
  } else if (data.imgType != null && data.imgType == constants.Network ||
      data.imgType == constants.network) {
    image = (data.imgPath == null)
        ? NetworkImage(constants.networkCardImagePath)
        : NetworkImage(data.imgPath);
  } else {
    image = NetworkImage(constants.networkCardImagePath);
  }
  return Container(
    decoration: data.containerDecoration != null
        ? data.containerDecoration
        : BoxDecoration(
            borderRadius: BorderRadius.circular(
                constants.heightTen + constants.heightFourrty),
            color: data.containerbgColor != null
                ? data.containerbgColor
                : mediumGreyThemeData().primaryColor,
          ),
    child: SingleChildScrollView(
      child: Column(
        children: <Widget>[
          Container(
            decoration: data.containerDecoration != null
                ? data.containerDecoration
                : BoxDecoration(
                    borderRadius: BorderRadius.circular(
                        constants.heightTen + constants.heightTwenty),
                    color: data.containerbgColor != null
                        ? data.containerbgColor
                        : mediumGreyThemeData().primaryColor,
                  ),
            child: SizedBox(
              width: data.containerWidth != null
                  ? data.containerWidth
                  : constants.heightFourHundred,
              height: data.containerHeight != null
                  ? data.containerHeight
                  : constants.heightFourHundred,
              child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: <Widget>[
                    Visibility(
                      visible: data.visibilityCardHeaderTile != null
                          ? data.visibilityCardHeaderTile
                          : false,
                      child: ListTile(
                        leading: Card(
                          shape: RoundedRectangleBorder(
                              side: BorderSide(
                                style: BorderStyle.none,
                                width: constants.heightOne,
                              ),
                              borderRadius: BorderRadius.circular(
                                  constants.heightFive + constants.heightTen)),
                          child: data.icon != null
                              ? data.icon
                              : Icon(
                                  Icons.album,
                                  size: constants.heightFifty,
                                  semanticLabel: constants.cardTitle,
                                ),
                          color: data.cardbgColor != null
                              ? data.cardbgColor
                              : mediumGreyThemeData().primaryColorLight,
                        ),
                        title: Text(
                            data.headerText != null
                                ? data.headerText
                                : constants.dialogHeader,
                            semanticsLabel: constants.cardTitle,
                            style: data.textStyle1 != null
                                ? data.textStyle1
                                : TextStyle(
                                    color:
                                        mediumGreyThemeData().primaryColorDark,
                                    fontSize: constants.fontMedium)),
                      ),
                    ),
                    Visibility(
                        visible: data.visibilityCardImage != null
                            ? data.visibilityCardImage
                            : true,
                        child: Semantics(
                          label: data.headerText != null
                              ? data.headerText
                              : constants.dialogHeader,
                          child: Container(
                            width: data.imgWidth != null
                                ? data.imgWidth
                                : constants.heightFourHundred,
                            height: data.imgHeight != null
                                ? data.imgHeight
                                : constants.heightTwoHundred,
                            decoration: data.imgDecoration != null
                                ? data.imgDecoration
                                : BoxDecoration(
                                    image: DecorationImage(
                                        image: (image != null)
                                            ? image
                                            : NetworkImage(
                                                constants.networkCardImagePath),
                                        fit: BoxFit.fill),
                                  ),
                          ),
                        )),
                    Visibility(
                      visible: data.visibilityCardFooter != null
                          ? data.visibilityCardFooter
                          : true,
                      child: Padding(
                          padding: data.padding1 != null
                              ? EdgeInsets.all(data.padding1)
                              : EdgeInsets.all(constants.heightTwenty),
                          child: ListTile(
                            title: Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: <Widget>[
                                Text(
                                  data.title != null
                                      ? data.title
                                      : constants.cardTitle,
                                  maxLines: constants.intOne,
                                  overflow: TextOverflow.ellipsis,
                                  style: data.textStyle2 != null
                                      ? data.textStyle2
                                      : TextStyle(
                                          fontSize: constants.heightTwentyFive,
                                        ),
                                ),
                                RatingBar(
                                  itemSize: constants.heightTwentyFive,
                                  initialRating: data.initialRating != null
                                      ? data.initialRating
                                      : constants.heightTwo,
                                  minRating: constants.heightOne,
                                  direction: Axis.horizontal,
                                  allowHalfRating: true,
                                  itemCount: constants.intFive,
                                  itemPadding: EdgeInsets.symmetric(
                                      horizontal: constants.heightFive),
                                  itemBuilder: (context, _) => Icon(
                                    Icons.star,
                                    color: data.ratingBarColor != null
                                        ? data.ratingBarColor
                                        : mediumGreyThemeData().highlightColor,
                                  ),
                                  onRatingUpdate: data.onRatingUpdate != null
                                      ? (rating) {
                                          data.onRatingUpdate(rating);
                                        }
                                      : (rating) {
                                          print(rating);
                                        },
                                ),
                                Text(
                                  data.subtitle != null
                                      ? data.subtitle
                                      : constants.dialogHeader,
                                  maxLines: constants.intOne,
                                  overflow: TextOverflow.ellipsis,
                                  style: data.textStyle3 != null
                                      ? data.textStyle3
                                      : TextStyle(
                                          fontSize: constants.fontLarger,
                                        ),
                                )
                              ],
                            ),
                            subtitle: Text(
                              data.bodyText != null
                                  ? data.bodyText
                                  : constants.dialogContent,
                              maxLines: constants.intTwo * constants.intTwo,
                              overflow: TextOverflow.ellipsis,
                              style: data.textStyle4 != null
                                  ? data.textStyle4
                                  : TextStyle(
                                      fontSize: constants.fontMedium,
                                    ),
                            ),
                          )),
                    ),
                    Visibility(
                        visible: data.visibilityCardData != null
                            ? data.visibilityCardData
                            : false,
                        child: Column(
                          children: <Widget>[
                            Divider(
                              endIndent: constants.heightTen,
                              thickness: constants.heightFive,
                              color: data.dividerColor != null
                                  ? data.dividerColor
                                  : mediumGreyThemeData().iconTheme.color,
                              indent: constants.heightTen,
                            ),
                            Text(
                              data.footerText != null
                                  ? data.footerText
                                  : constants.dialogHeader,
                              style: data.textStyle5 != null
                                  ? data.textStyle5
                                  : TextStyle(
                                      fontSize: constants.heightTwenty,
                                    ),
                              textAlign: TextAlign.justify,
                            ),
                            Column(
                              children: data.btnGrpList1 == null
                                  ? []
                                  : data.btnGrpList1,
                            ),
                          ],
                        )),
                    Visibility(
                      visible: data.visibilityCardActionBar != null
                          ? data.visibilityCardActionBar
                          : false,
                      child: Column(
                        children:
                            data.btnGrpList2 == null ? [] : data.btnGrpList2,
                      ),
                    )
                  ]),
            ),
          ),
        ],
      ),
    ),
  );
}
