/*
Widget Name:
- Simple Dialog

Description:
- Simple Dialog can be used to display the dialog message with OK and Cancel buttons.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-simple-dialog.dart';

Usage:
- Defining the callback and Simple Dialog objects

   onclickDialogBtn(int nIndex, String sText) {
    print(nIndex);
    print(sText);
  }
  final SimpleDialogData SimpleDialogdata = new SimpleDialogData(dialogButtonText: 'okay',btnTextColor: Colors.white,btnColor: Colors.pink,bodyTextColor: Colors.black,
      shapeBorder: RoundedRectangleBorder(
          side: BorderSide(
              style: BorderStyle.solid,
              color: Colors.black,
              width: 2
          ),
          borderRadius: BorderRadius.circular(10)),bgColor: Colors.white);

- Widget call
              FlatButton(child:Text('Show Simple Dialog'),onPressed:(){showDialog(
            context: context,
            builder: (context) => simpleDialogWidget(
                SimpleDialogdata, context, onclickDialogBtn));},color: Colors.pink,

    )
Author:
Satyabrat Padhy
*/

import "package:flutter/material.dart";
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/consts.dart' as constants;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget simpleDialogWidget(
    SimpleDialogData data, context, void Function(int, String) callback) {
  return SimpleDialog(
    elevation: constants.heightTen,
    backgroundColor: data.bgColor != null
        ? data.bgColor
        : mediumGreyThemeData().primaryColor,
    title: Text(
      (data.dialogHeader != null) ? data.dialogHeader : constants.dialogHeader,
      textAlign: TextAlign.center,
      style: TextStyle(
          color: data.headerTextColor != null
              ? data.headerTextColor
              : mediumGreyThemeData().accentIconTheme.color),
    ),
    children: <Widget>[
      Container(
        padding: EdgeInsets.all(constants.heightThirty),
        height:
            (data.height != null) ? data.height : constants.heightTwoHundred,
        width: (data.width != null) ? data.width : constants.heightTwoHundred,
        child: SingleChildScrollView(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: <Widget>[
              SizedBox(
                height: constants.heightTwenty,
              ),
              Text(
                (data.dialogContent != null)
                    ? data.dialogContent
                    : constants.dialogContent,
                style: TextStyle(
                  color: data.bodyTextColor != null
                      ? data.bodyTextColor
                      : mediumGreyThemeData().accentIconTheme.color,
                  fontSize: constants.fontLarger,
                ),
              ),
            ],
          ),
        ),
      ),
      Container(
        padding: EdgeInsets.all(constants.heightThirty),
        child: ButtonBar(
          children: <Widget>[
            SizedBox(
              child: FlatButton(
                padding: EdgeInsets.all(constants.heightTen),
                child: Text(
                  (data.dialogButtonText != null)
                      ? data.dialogButtonText
                      : constants.dialogButtonText,
                  style: TextStyle(
                    color: data.btnTextColor != null
                        ? data.btnTextColor
                        : mediumGreyThemeData().textSelectionColor,
                    fontSize: constants.fontLarger,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                color: data.btnColor != null
                    ? data.btnColor
                    : mediumGreyThemeData().buttonColor,
                onPressed: () {
                  callback(constants.intOne, constants.dialogHeader);
                },
              ),
              width: constants.heightHundred + constants.heightTwenty,
            ),
            SizedBox(
              width: constants.heightTen,
            ),
            SizedBox(
              child: FlatButton(
                padding: EdgeInsets.all(constants.heightTen),
                child: Text(
                  constants.cancelButtonText,
                  style: TextStyle(
                    color: data.btnTextColor != null
                        ? data.btnTextColor
                        : mediumGreyThemeData().textSelectionColor,
                    fontSize: constants.fontLarger,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                color: data.btnColor != null
                    ? data.btnColor
                    : mediumGreyThemeData().buttonColor,
                onPressed: () {
                  Navigator.of(context).pop();
                },
              ),
              width: constants.heightHundred + constants.heightTwenty,
            )
          ],
        ),
      )
    ],
    shape: data.shapeBorder != null
        ? data.shapeBorder
        : RoundedRectangleBorder(
            side: BorderSide(
              style: BorderStyle.none,
            ),
            borderRadius: BorderRadius.circular(constants.heightTen)),
  );
}
