/*
Imports Required:
import 'package:flutter/material.dart';
import 'custom-videoplayer.dart';
video_player: ^0.10.11 dependency is added to pubspec.yaml file.
chewie: ^0.9.10 dependency is added to pubspec.yaml file.

Widget can be parameterised as follows:
A video link has to be sent as mandatory. And "type" has to be mentioned as 'network' or 'asset' based on the source.
The backgroundColour, bufferedColour, playedColour and handleColour can be passed or will be set to default values.
The aspectRatio can be specified or it will be set as 16/9 as default.
looping, autoPlay, showControls, can be enabled or disabled by setting them to true/false. They are all true by default.

SAMPLE IMPLEMENTATION:

CustomVideoPlayer video = new CustomVideoPlayer(
      videolink: 'https://www.learningcontainer.com/wp-content/uploads/2020/05/sample-mp4-file.mp4',
      backgroundColor: Colors.grey,
      aspectRatio: 4/3,
      type: 'network',
      looping: true,
      autoPlay: false,
      showControls: true,
      bufferedColor: Colors.grey,
      playedColor: Colors.red,
      handleColor: Colors.red,
    );
body: Center(child: video)

AUTHOR: Soumyadeep Mitra
*/

import 'package:chewie/chewie.dart';
// ignore: implementation_imports
//import 'package:chewie/src/chewie_player.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:video_player/video_player.dart';

class CustomVideoPlayer extends StatefulWidget {
  CustomVideoPlayer(
      {this.aspectRatio,
      this.autoPlay,
      this.looping,
      this.showControls,
      this.playedColor,
      this.handleColor,
      this.backgroundColor,
      this.bufferedColor,
      this.videolink,
      this.type});
  final String type;
  final String videolink;
  final double aspectRatio;
  final bool autoPlay;
  final bool looping;
  final bool showControls;
  final Color playedColor;
  final Color handleColor;
  final Color backgroundColor;
  final Color bufferedColor;

  @override
  State<StatefulWidget> createState() {
    return _CustomVideoPlayerState();
  }
}

class _CustomVideoPlayerState extends State<CustomVideoPlayer> {
  VideoPlayerController videoPlayerController1;
  ChewieController _chewieController;

  @override
  void initState() {
    super.initState();
    if (widget.type == "network") {
      videoPlayerController1 = VideoPlayerController.network(widget.videolink);
    } else if (widget.type == "asset") {
      videoPlayerController1 = VideoPlayerController.asset(widget.videolink);
    }

    _chewieController = ChewieController(
      videoPlayerController: videoPlayerController1,
      aspectRatio: widget.aspectRatio == null ? 16 / 9 : widget.aspectRatio,
      autoPlay: widget.autoPlay == null ? true : widget.autoPlay,
      looping: widget.looping == null ? true : widget.looping,
      showControls: widget.showControls == null ? true : widget.showControls,
      materialProgressColors: ChewieProgressColors(
        playedColor: widget.playedColor == null
            ? Theme.of(context).backgroundColor
            : widget.playedColor,
        handleColor: widget.handleColor == null
            ? Theme.of(context).primaryColorDark
            : widget.handleColor,
        backgroundColor: widget.backgroundColor == null
            ? Theme.of(context).backgroundColor
            : widget.backgroundColor,
        bufferedColor: widget.bufferedColor == null
            ? Theme.of(context).accentColor
            : widget.bufferedColor,
      ),
      autoInitialize: true,
    );
  }

  @override
  void dispose() {
    videoPlayerController1.dispose();
    _chewieController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Expanded(
          child: Center(
            child: Chewie(
              controller: _chewieController,
            ),
          ),
        ),
      ],
    );
  }
}
